<?php
/**
*
* acp_common.php [Sorani Kurdish]
*
* @package language
* @version $Id: $
* @copyright (c) 2009 phpBB Group
* @author 2009-06-06 - Chawg.org Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

$lang = array_merge($lang, array(
	'ACP_ADMINISTRATORS'	=> 'بەڕێوەبەران',
	'ACP_ADMIN_LOGS'	=> 'لۆگی بەڕێوەبەر',
	'ACP_ADMIN_ROLES'	=> 'پلەکانی بەڕێوەبەر',
	'ACP_ATTACHMENTS'	=> 'هاوپێچەکان',
	'ACP_ATTACHMENT_SETTINGS'	=> 'ڕێکخستنەکانی هاوپێچ',
	'ACP_AUTH_SETTINGS'	=> 'دڵنیاکردن',
	'ACP_AUTOMATION'	=> 'خۆکارەئاگایی',
	'ACP_AVATAR_SETTINGS'	=> 'ڕێکخستنەکانی وێنۆچکە',
	'ACP_BACKUP'	=> 'پشتگیری',
	'ACP_BAN'	=> 'ڕاگرتن',
	'ACP_BAN_EMAILS'	=> 'قەدەغەکردنی ئیمەیل',
	'ACP_BAN_IPS'	=> 'قەدەغەکردنی IP',
	'ACP_BAN_USERNAMES'	=> 'ڕاگرتنی ناو بەکارهێنەران',
	'ACP_BBCODES'	=> 'BBCode ـەکان',
	'ACP_BOARD_CONFIGURATION'	=> 'سازدانی مەکۆ',
	'ACP_BOARD_FEATURES'	=> 'تایبەتمەندییەکانی مەکۆ',
	'ACP_BOARD_MANAGEMENT'	=> 'بەڕێوەبردنی مەکۆ',
	'ACP_BOARD_SETTINGS'	=> 'ڕێکخستنەکانی مەکۆ',
	'ACP_BOTS'	=> 'جاڵجاڵۆکەکان/ڕۆبۆتەکان',
	'ACP_CAPTCHA'	=> 'CAPTCHA',
	'ACP_CAT_DATABASE'	=> 'بنکەدراوە',
	'ACP_CAT_DOT_MODS'	=> '.MODs',
	'ACP_CAT_FORUMS'	=> 'مەکۆکان',
	'ACP_CAT_GENERAL'	=> 'گشتیی',
	'ACP_CAT_MAINTENANCE'	=> 'چاکسازیی',
	'ACP_CAT_PERMISSIONS'	=> 'دەسەڵاتەکان',
	'ACP_CAT_POSTING'	=> 'ناردن',
	'ACP_CAT_STYLES'	=> 'ڕووخسارەکان',
	'ACP_CAT_SYSTEM'	=> 'سیستەم',
	'ACP_CAT_USERGROUP'	=> 'بەکارهێنەران و گرووپەکان',
	'ACP_CAT_USERS'	=> 'بەکارهێنەران',
	'ACP_CLIENT_COMMUNICATION'	=> 'پەیوەندییەکانی ڕاژەخواز',
	'ACP_COOKIE_SETTINGS'	=> 'ڕێکخستنەکانی کووکی',
	'ACP_CRITICAL_LOGS'	=> 'لۆگی هەڵە',
	'ACP_CUSTOM_PROFILE_FIELDS'	=> 'خانە دەستکردەکانی پڕۆفایل',
	'ACP_DATABASE'	=> 'بەڕێوەبردنی بنکەدراوە',
	'ACP_DISALLOW'	=> 'ڕێگرتن',
	'ACP_DISALLOW_USERNAMES'	=> 'ڕێگرتن لە ناوی بەکارهێنەر',
	'ACP_EMAIL_SETTINGS'	=> 'ڕێکخستنەکانی ئیمەیل',
	'ACP_EXTENSION_GROUPS'	=> 'گرووپە گەیەنەرەکان بەڕێوەببە',
	'ACP_FORUM_BASED_PERMISSIONS'	=> 'دەسەڵاتەکانی پەیوەست بە مەکۆ',
	'ACP_FORUM_LOGS'	=> 'لۆگەکانی مەکۆ',
	'ACP_FORUM_MANAGEMENT'	=> 'بەڕێوەبردنی مەکۆ',
	'ACP_FORUM_MODERATORS'	=> 'چاودێرانی مەکۆ',
	'ACP_FORUM_PERMISSIONS'	=> 'دەسەڵاتەکانی مەکۆ',
	'ACP_FORUM_PERMISSIONS_COPY'	=> 'دەسەڵاتەکانی مەکۆ ڕوونووس بکە',
	'ACP_FORUM_ROLES'	=> 'ۆلەکانی مەکۆ',
	'ACP_GENERAL_CONFIGURATION'	=> 'شێوەپێدانی گشتیی',
	'ACP_GENERAL_TASKS'	=> 'ئەرکە گشتییەکان',
	'ACP_GLOBAL_MODERATORS'	=> 'چاودێرە گشتییەکان',
	'ACP_GLOBAL_PERMISSIONS'	=> 'دەسەڵاتە گشتییەکان',
	'ACP_GROUPS'	=> 'گرووپەکان',
	'ACP_GROUPS_FORUM_PERMISSIONS'	=> 'دەسەڵاتەکانی مەکۆی گرووپەکان',
	'ACP_GROUPS_MANAGE'	=> 'بەڕێوەبردنی گرووپەکان',
	'ACP_GROUPS_MANAGEMENT'	=> 'بەڕێوەردنی گرووپ',
	'ACP_GROUPS_PERMISSIONS'	=> 'دەسەڵاتەکانی گرووپەکان',
	'ACP_ICONS'	=> 'ئایکۆنەکانی بابەت',
	'ACP_ICONS_SMILIES'	=> 'هێما/خەندەکانی بابەت',
	'ACP_IMAGESETS'	=> 'Imagesets',
	'ACP_INACTIVE_USERS'	=> 'بەکارهێنەرە ناچالاکەکان',
	'ACP_INDEX'	=> 'دەستپێکی ACP',
	'ACP_JABBER_SETTINGS'	=> 'ڕێکخستنەکانی جابەر',
	'ACP_LANGUAGE'	=> 'بەڕێوەبردنی زمان',
	'ACP_LANGUAGE_PACKS'	=> 'گورزەکانی زمان',
	'ACP_LOAD_SETTINGS'	=> 'کردنەوە ڕێکخستنەکان',
	'ACP_LOGGING'	=> 'چوونە ژوورەوە',
	'ACP_MAIN'	=> 'دەستپێکی ACP',
	'ACP_MANAGE_EXTENSIONS'	=> 'بەڕێوەبردنی درێژکراوەکان',
	'ACP_MANAGE_FORUMS'	=> 'بەڕێوەبردنی مەکۆکان',
	'ACP_MANAGE_RANKS'	=> 'بەڕێوەبردنی پلەکان',
	'ACP_MANAGE_REASONS'	=> 'هۆکارەکانی ریپۆرت/ڕەتکردن بەڕێوەببە',
	'ACP_MANAGE_USERS'	=> 'بەڕێوەبردنی بەکارهێنەران',
	'ACP_MASS_EMAIL'	=> 'ئیمەیڵی گشتی',
	'ACP_MESSAGES'	=> 'پەیامەکان',
	'ACP_MESSAGE_SETTINGS'	=> 'ڕێکخستنەکانی پەیامی تایبەت',
	'ACP_MODULE_MANAGEMENT'	=> 'بەڕێوەبردنی یەکەکان',
	'ACP_MOD_LOGS'	=> 'لۆگی چاودێر',
	'ACP_MOD_ROLES'	=> 'پلەکانی چاودێر',
	'ACP_NO_ITEMS'	=> 'تا ئێستا هیچ دانەیەک نییە.',
	'ACP_ORPHAN_ATTACHMENTS'	=> 'هاوپێچە هەتیوەکان',
	'ACP_PERMISSIONS'	=> 'دەسەڵاتەکان',
	'ACP_PERMISSION_MASKS'	=> 'دەمامکەکانی دەسەڵات',
	'ACP_PERMISSION_ROLES'	=> 'یاساکانی دەسەڵات',
	'ACP_PERMISSION_TRACE'	=> 'شوێنەواری دەسەڵات',
	'ACP_PHP_INFO'	=> 'زانیارییەکانی PHP',
	'ACP_POST_SETTINGS'	=> 'ڕێکخستنەکانی ناردن',
	'ACP_PRUNE_FORUMS'	=> 'پاککردنەوەی مەکۆکان',
	'ACP_PRUNE_USERS'	=> 'پاککردنەوەی بەکارهێنەران',
	'ACP_PRUNING'	=> 'پاککردنەوە',
	'ACP_QUICK_ACCESS'	=> 'دەستپێڕاگەیشتنی خێرا',
	'ACP_RANKS'	=> 'پلەکان',
	'ACP_REASONS'	=> 'هۆکارەکانی ریپۆرت/ڕەتکردن',
	'ACP_REGISTER_SETTINGS'	=> 'ڕێکخستنەکانی خۆتۆمارکردنی بەکارهێنەران',
	'ACP_RESTORE'	=> 'گێڕاندنەوە',
	'ACP_FEED'	=> 'بەڕێوەبردنی Feed',
	'ACP_FEED_SETTINGS' => 'ڕێکخستنەکانی Feed',
	'ACP_SEARCH'	=> 'سازدانی گەڕان',
	'ACP_SEARCH_INDEX'	=> 'دەستپێکی گەڕان',
	'ACP_SEARCH_SETTINGS'	=> 'ڕێکخستنەکانی گەڕان',
	'ACP_SECURITY_SETTINGS'	=> 'ڕێکخستنەکانی ئاسایش',
	'ACP_SEND_STATISTICS'		=> 'زانیاری ئاماری بنێرە',
	'ACP_SERVER_CONFIGURATION'	=> 'سازدانی ڕاژەکار',
	'ACP_SERVER_SETTINGS'	=> 'ڕێکخستنەکانی ڕاژەکار',
	'ACP_SIGNATURE_SETTINGS'	=> 'ڕێکخستنەکانی واژۆ',
	'ACP_SMILIES'	=> 'خەندەکن',
	'ACP_STYLE_COMPONENTS'	=> 'پێکهاتەکانی ڕووخسار',
	'ACP_STYLE_MANAGEMENT'	=> 'بەڕێوەبردنی ڕووخسار',
	'ACP_STYLES'	=> 'ڕووخسارەکان',
	'ACP_SUBMIT_CHANGES'		=> 'گۆڕانکارییەکان بنێرە',
	'ACP_TEMPLATES'	=> 'قاڵبەکان',
	'ACP_THEMES'	=> 'ڕووکارەکان',
	'ACP_UPDATE'	=> 'نوێکردنەوە',
	'ACP_USERS_FORUM_PERMISSIONS'	=> 'دەسەڵاتەکانی مەکۆی بەکارهێنەران',
	'ACP_USERS_LOGS'	=> 'لۆگەکانی بەکارهێنەر',
	'ACP_USERS_PERMISSIONS'	=> 'دەسەڵاتەکانی بەکارهێنەران',
	'ACP_USER_ATTACH'	=> 'هاوپێچەکان',
	'ACP_USER_AVATAR'	=> 'وێنۆچکە',
	'ACP_USER_FEEDBACK'	=> 'Feedback',
	'ACP_USER_GROUPS'	=> 'گرووپەکان',
	'ACP_USER_MANAGEMENT'	=> 'بەڕێوەبردنی بەکارهێنەر',
	'ACP_USER_OVERVIEW'	=> 'ڕووکەش',
	'ACP_USER_PERM'	=> 'دەسەڵاتەکان',
	'ACP_USER_PREFS'	=> 'ویستراوەکان',
	'ACP_USER_PROFILE'	=> 'پڕۆفایل',
	'ACP_USER_RANK'	=> 'پلە',
	'ACP_USER_ROLES'	=> 'پلەکانی بەکارهێنەر',
	'ACP_USER_SECURITY'	=> 'ئاساییشیی بەکارهێنەر',
	'ACP_USER_SIG'	=> 'واژۆ',
	'ACP_USER_WARNINGS'	=> 'ئاگادارییەکان',
	'ACP_VC_SETTINGS'					=> 'ژمێریاری سپام',
	'ACP_VC_CAPTCHA_DISPLAY'	=> 'پێشبینینی وێنەی CAPTCHA',
	'ACP_VERSION_CHECK'	=> 'پشکنین بۆ نوێکردنەوە',
	'ACP_VIEW_ADMIN_PERMISSIONS'	=> 'دەسەڵاتی بەڕێوەبردن ببینە',
	'ACP_VIEW_FORUM_MOD_PERMISSIONS'	=> 'دەسەڵاتی چاودێرانی مەکۆ ببینە',
	'ACP_VIEW_FORUM_PERMISSIONS'	=> 'دەسەڵاتی بنچینەکراو-مەکۆ ببینە',
	'ACP_VIEW_GLOBAL_MOD_PERMISSIONS'	=> 'دەسەڵاتی چاودێرە جیهانییەکان ببینە',
	'ACP_VIEW_USER_PERMISSIONS'	=> 'دەسەڵاتی بنچینەکراو-بەکارهێنەر ببینە',
	'ACP_WORDS'	=> 'قەدەغەکردنی وشە',
	'ACTION'	=> 'چالاکی',
	'ACTIONS'	=> 'جالاکییەکان',
	'ACTIVATE'	=> 'چالاککردن',
	'ADD'	=> 'زیادکردن',
	'ADMIN'	=> 'بەڕێوەبەرایەتی',
	'ADMIN_INDEX'	=> 'دەستپێکی بەڕێوەبەرایەتی',
	'ADMIN_PANEL'	=> 'کۆنترۆڵ پانێلی بەڕێوەبەرایەتی',
	'ADM_LOGOUT'	=> 'دەرچوون لە&nbsp;ACP',
	'ADM_LOGGED_OUT'	=> 'بەسەرکەوتوویی چوویتە دەرەوە لە کۆنترۆڵ پانێڵی بەڕێوەبەرایەتی',
	'BACK'	=> 'دواوە',
	'COLOUR_SWATCH'	=> 'ڕەنگی ئاڵوگۆڕی وێب-پارێز',
	'CONFIG_UPDATED'	=> 'دیمەنکردن بەسەرکەوتوویی نوێکرایەوە.',
	'DEACTIVATE'	=> 'ناچالاککردن',
	'DIRECTORY_DOES_NOT_EXIST'	=> 'ڕێڕەوی لێدراو “%s”بوونی نییە.',
	'DIRECTORY_NOT_DIR'	=> 'ڕێڕەوی لێدراو “%s” بوخچە نییە.',
	'DIRECTORY_NOT_WRITABLE'	=> 'ڕێڕەوی لێدراو “%s” توانای نووسینەوە لەسەر نییە.',
	'DISABLE'	=> 'ناچالاککردن',
	'DOWNLOAD'	=> 'داگرتن',
	'DOWNLOAD_AS'	=> 'داگرتن وەک',
	'DOWNLOAD_STORE'	=> 'داگرتن یان پاشەکەوتکردنی پەڕگە',
	'DOWNLOAD_STORE_EXPLAIN'	=> 'پێویستە ڕاستەوخۆ پەڕگەکە دابگریت یان پاشەکەوتی بکەیت بۆ بوخچەی <samp>store/</samp>.',
	'EDIT'	=> 'دەستکاری',
	'ENABLE'	=> 'چالاککردن',
	'EXPORT_DOWNLOAD'	=> 'داگرتن',
	'EXPORT_STORE'	=> 'پاشەکەوتکردن',
	'GENERAL_OPTIONS'	=> 'هەڵبژاردنە گشتییەکان',
	'GENERAL_SETTINGS'	=> 'ڕێکخستنە گشتییەکان',
	'GLOBAL_MASK'	=> 'دەمامکی دەسەڵاتی جیهانی',
	'INSTALL'	=> 'دامەزراندن',
	'IP'	=> 'IP بەکارهێنەر',
	'IP_HOSTNAME'	=> 'ناونیشانی IP یان ناوی ڕاژە',
	'LOGGED_IN_AS'	=> 'لە ژوورەوەیت وەک:',
	'LOGIN_ADMIN'	=> 'بۆ بەڕێوەبردنی مەکۆکەت پێویستە تۆ بەکارهێنەرێکی دڵنیاکراو بیت.',
	'LOGIN_ADMIN_CONFIRM'	=> 'بۆ بەڕێوەبردنی مەکۆکەت پێویستە دووبارە خۆت دڵنیابکەیتەوە',
	'LOGIN_ADMIN_SUCCESS'	=> 'بە سەرکەوتوویی دڵنیاکرایتەوە ،ئێستا دەگەڕێندرێیتەوە بۆ کۆنترۆڵ پانێڵی بەڕێوەبەرایەتی',
	'LOOK_UP_FORUM'	=> 'مەکۆیەک دیاری بکە',
	'LOOK_UP_FORUMS_EXPLAIN'	=> 'ئەتوانیت زیاد لە مەکۆیەک دیاری بکەیت.',
	'MANAGE'	=> 'بەڕێوەبردن',
	'MENU_TOGGLE'	=> 'مێنیوی لاتەنیشت بشارەوە یان پیشانی بدە',
	'MORE'					=> 'زیاتر',			// Not used at the moment
	'MORE_INFORMATION'		=> 'زانیاری زیاتر »',
	'MOVE_DOWN'	=> 'جوڵان بۆ سەرەوە',
	'MOVE_UP'	=> 'جوڵان بۆ خوارەوە',
	'NOTIFY'	=> 'ئاگادارکردنەوە',
	'NO_ADMIN'	=> 'تۆ ڕێگات پێ نەدراوە بۆ بەڕێوەبردنی ئەو مەکۆیە',
	'NO_EMAILS_DEFINED'	=> 'هیچ ناونیشانێکی ئیمەیڵی دروست نەدۆزرایەوە.',
	'NO_PASSWORD_SUPPLIED'	=> 'پێویستە تێپەڕەوشەکەت بنووسی بۆ گەیشتن بە کۆنترۆڵ پانێڵی بەڕێوەبەرایەتی.',
	'OFF'	=> 'ناکارا',
	'ON'	=> 'کارا',
	'PROCEED_TO_ACP'	=> '%sبڕۆ بۆ ACP%s',
	'REMIND'	=> 'بیرهێنان',
	'RESYNC'	=> 'ڕاگواستن',
	'RETURN_TO'	=> 'بگەڕێوە بۆ...',
	'SELECT_ANONYMOUS'	=> 'بەکارهێنەرێکی نەناسراو دیاری بکە',
	'SELECT_OPTION'	=> 'هەڵبژاردنێک دیاری بکە',
	'SETTING_TOO_LOW'		=> 'نرخی دراو بۆ ئەو ڕێکخستنە “%1$s” زۆر نزمە. کەمترین نرخی وەرگیراو بریتییە لە %2$d.',
	'SETTING_TOO_BIG'		=> 'نرخی دراو بۆ ئەو ڕێکخستنە “%1$s” زۆر بەرزە. زۆرترین نرخی وەرگیراو بریتییە لە %2$d.',
	'SETTING_TOO_LONG'		=> 'نرخی دراو بۆ ئەو ڕێکخستنە “%1$s” زۆر درێژە. زۆرترین درێژی وەرگیراو بریتییە لە %2$d.',
	'SETTING_TOO_SHORT'		=> 'نرخی دراو بۆ ئەو ڕێکخستنە “%1$s” زۆر کورتە. کەمترین درێژی وەرگیراو بریتییە لە %2$d.',
	'SHOW_ALL_OPERATIONS'	=> 'هەموو کردارەکان نیشانبدە',
	'UCP'	=> 'کۆنترۆڵ پانێڵی بەکارهێنەر',
	'USERNAMES_EXPLAIN'	=> 'ناوی هەر بەکارهێنەرێک لە هێڵێکی جیا دابنێ.',
	'USER_CONTROL_PANEL'	=> 'کۆنترۆڵ پانێڵی بەکارهێنەر',
	'WARNING'	=> 'ئاگاداری',
	'ACP_PHP_INFO_EXPLAIN'	=> 'ئەو پەڕەیە زانیاری لیستکردووە لەسەر وەشانی دامەزراوی PHP لەسەر ئەو ڕاژەیە ،وردەکاری بارکراوی یەکەسەربەخۆکان لەخۆدەگرێت ،گۆڕاوە بەردەستەکان لەگەڵ ڕێکخستنە بنەڕەتییەکان. ئەو زانیارییە لەوانەیە بەسوود بێت کاتی کێشە کەسییەکان. تکایە وریابە کە هەندێ کۆمپانیای خانەخوێکردن ئەوە سنووردار دەکەن کە چ زانیارییەک نیشان دەدرێت لێرە بۆ هۆکارەکانی پاراستن. تۆ ئامۆژگاری کراوی بۆ پێنەدانی هیچ وردەکارییەک لەسەر ئەو پەڕەیە ،بێجگە لەوەی کە داوات لێکرا لەلایەن <a href="http://www.phpbb.com/about/team/">تیپی فەرمی ئەندامان</a> لە مەکۆکانی پاڵپشتی.',
	'NO_PHPINFO_AVAILABLE'	=> 'زانیاری دەربارەی دیمەنکردنی PHP ــەکەت ناتوانێت دیاریبکرێت. Phpinfo() ناچالاککراوە بۆ هۆکارەکانی پاراستن.',
	'ACP_ADMIN_LOGS_EXPLAIN'	=> 'ئەوە هەموو کردارە هەڵگیراوەکان لیست دەکات لەلایەن بەڕێوەبەرانی مەکۆ. دەتوانی ڕیزبەندی بکەی بەهۆی ناوی بەکارهێنەر ،بەروار ،IP یان کردار. ئەگەر دەسەڵاتی بەرامبەرکێت هەیە دەتوانی کردارەکە تەواو نادروستەکان لابەریت یان تۆمارکەرەکە وەکو چاڵێک.',
	'ACP_CRITICAL_LOGS_EXPLAIN'	=> 'ئەمە کردارەکە هەڵگیراوەکان لیست دەکات لەلایەن خودی مەکۆکە. ئەو لۆگە زانیاری دەسەڵاتی بەرامبەرکێ پێدەدات دەتوانی کردارە ماوەکان لابەریت یان لۆگە وەکو چاڵێک.',
	'ACP_MOD_LOGS_EXPLAIN'	=> 'ئەمە هەموو کردارە کراوەکان لیست دەکات لەسەر مەکۆکان ،بابەتەکان و پەیامەکان وەکو باسی وەکو کردارە هەڵگیراوەکان لەسەر بەکارهێنەران لەلایەن چاودێران. لەناویاندا ڕاگرتن. دەتوانی ڕیزبەندی بکەیت بەهۆی ناوی بەکارهێنەر ،داتا ،IP یان کردار. ئەگەر تۆ دەسەڵاتی بەرامبەرکێت هەیە دەشتوانی کردارە ماوەکان لابەریت یان تۆمارهەرییەکە وەکو چاڵێک.',
	'ACP_USERS_LOGS_EXPLAIN'	=> 'ئەمە هەموو کردارە هەڵگیراوەکان لیست دەکات لەلایەن بەکارهێنەران یان لەسەر بەکارهێنەران.',
	'ALL_ENTRIES'	=> 'هەموو دانەکان',
	'DISPLAY_LOG'	=> 'دەروازەکان نیشانبدە لە پێشووەکان',
	'NO_ENTRIES'	=> 'هیچ لۆگی دەروازە نییە بۆ ئەو ماوەیە',
	'SORT_IP'	=> 'ناونیشانی IP',
	'SORT_DATE'	=> 'ڕێکەوت',
	'SORT_ACTION'	=> 'چالاکی لۆگ',
	'ADMIN_INTRO'	=> 'سوپاس بۆ هەڵبژاردنی phpBB وەکو پێکهێنەری مەکۆکەت. ئەو پەردەیە پێداچوونەوەیەکی خێرات پێدەدات لە هەموو ئامارە هەمەجۆرەکانی مەکۆکەت. بەستەرەکانی لای چەپی پەردەکە ڕێگات دەدەن بۆ کۆنترۆڵ کردنی هەر جووڵە/کردارێکی ئەزموونیی مەکۆکەت. هەر پەڕەیەک ڕێنوویی خۆی هەیە لەسەر چۆنیەتی بەکارهێنانی ئامرازەکان.',
	'ADMIN_LOG'	=> 'کردارە لۆگکراوەکانی بەڕێوەبەر',
	'ADMIN_LOG_INDEX_EXPLAIN'	=> 'ئەمە پێداچوونەوەیەکی دوایین پێنج کردارە هەڵگیراوەکان دەدات لەلایەن بەڕێوەبەرانی مەکۆ. لەبەرگیراوێکی تەواوی لۆگەکە دەتوانێ ببینرێ لە شتەکانی مێنو یان بەدواکەوتنی ئەو بەستەرە.',
	'AVATAR_DIR_SIZE'	=> 'قەبارەی بوخچەی وێنۆچکە',
	'BOARD_STARTED'	=> 'دەستپێکردنی مەکۆ',
	'BOARD_VERSION'	=> 'وەشانی مەکۆ',
	'DATABASE_SERVER_INFO'	=> 'ڕاژەکاری بنکەدراوە',
	'DATABASE_SIZE'	=> 'قەبارەی بنکەدراوە',
	// Enviroment configuration checks, mbstring related
	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'بارستایی زیادی نەخشە بە ناڕێکی پەسەندکرا',
	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> پێویستە نرخەکەی بۆ 0 یان 4 دابنرێت. دەتوانی نرخی ئێستای بپشکنی لە پەڕەی <samp>زانیاری PHP</samp>.',
	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'کۆدکردنی ڕۆشنایی تیپەکان بە ناڕێکی پەسەندکرا',
	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> پێویستە نرخەکەی بۆ 0 دابنرێت. دەتوانی نرخی ئێستای بپشکنی لە پەڕەی <samp>زانیاری PHP</samp>.',
	'ERROR_MBSTRING_HTTP_INPUT'						=> 'گۆڕینی تیپی پشکی HTTP بە ناڕێکی پەسەندکرا',
	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> پێویستە نرخەکەی دابنرێ بۆ <samp>pass</samp>. دەتوانی نرخی ئێستای بپشکنی لە پەڕەی <samp>زانیاری PHP</samp>.',
	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'گۆڕینی تیپی بەرهەمی HTTP بە ناڕێکی پەسەندکرا',
	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> پێویستە نرخەکەی دابنرێ بۆ <samp>pass</samp>. دەتوانی نرخی ئێستای بپشکنی لە پەڕەی <samp>زانیاری PHP</samp>.',
	'FILES_PER_DAY'	=> 'هاوپێچەکان بۆ هەر ڕۆژێک',
	'FORUM_STATS'	=> 'ئامارەکانی مەکۆ',
	'GZIP_COMPRESSION'	=> 'پەستاندنی GZip',
	'NOT_AVAILABLE'	=> 'ئامادە نییە',
	'NUMBER_FILES'	=> 'ژمارەی هاوپێچەکان',
	'NUMBER_POSTS'	=> 'ژمارەی پەیامەکان',
	'NUMBER_TOPICS'	=> 'ژمارەی بابەتەکان',
	'NUMBER_USERS'	=> 'ژمارەی بەکارهێنەران',
	'NUMBER_ORPHAN'	=> 'هاوپێچە هەتیوەکان',
	'PHP_VERSION_OLD'	=> 'ئەو وەشانەی PHP لەسەر ئەو ڕاژەیە هیچی تر پاڵپشتی ناکرێت لەلایەن وەشانە داهاتووەکانی phpBB. %sوردەکارییەکان%s',
	'POSTS_PER_DAY'	=> 'پەیامەکان بۆ هەر ڕۆژێک',
	'PURGE_CACHE'	=> 'پاککردنەوەی ئەرشیفەکە',
	'PURGE_CACHE_CONFIRM'	=> 'دڵنیایت لە بەردەوامبوون بۆ پاککردنەوەی ئەرشیفەکە؟',
	'PURGE_CACHE_EXPLAIN'	=> 'هەموو شتە پەیوەندیدارەکانی ئەرشیف پاکبکەوە ،ئەمە هەر پەڕگە یان پرسگەکانی داڕێژەیەکی ئەرشیف لەخۆ دەگرێت.',
	'PURGE_SESSIONS'			=> 'هەموو دانیشتنەکان پاکبکەوە',
	'PURGE_SESSIONS_CONFIRM'	=> 'دڵیایت لە بەردەوامبوون بۆ پاککردنەوەی هەموو دانیشتنەکان؟ ئەمە هەموو بەکارهێنەران دەخاتە دەرەوە.',
	'PURGE_SESSIONS_EXPLAIN'	=> 'هەموو دانیشتنەکان پاکبکەوە. ئەمە هەموو بەکارهێنەران دەخاتە دەرەوە بە هەڵگرتنی خشتەی دانیشتن.',
	'RESET_DATE'	=> 'بەرواری سەرەتای مەکۆ دابنێوە',
	'RESET_DATE_CONFIRM'	=> 'دڵنیایت لە بەردەوامبوون بۆ دانانەوەی بەرواری سەرەتای مەکۆکە؟',
	'RESET_ONLINE'	=> 'زۆرترین بەکارهێنەری سەرهێڵ دابنێوە',
	'RESET_ONLINE_CONFIRM'	=> 'دڵنیایت لە بەردەوامبوون بۆ دانانەوەی ژمێریاری زۆرترین بەکارهێنەری سەرهێڵ؟',
	'RESYNC_POSTCOUNTS'	=> 'لەگەڵهاتنەوەی ژمارەی پەیام',
	'RESYNC_POSTCOUNTS_EXPLAIN'	=> 'تەنها پەیامە چالاکەکان دەبرێن بۆناو گرنگیدان. پەیامە وشکەکان هەژمار ناکرێن.',
	'RESYNC_POSTCOUNTS_CONFIRM'	=> 'دڵنیایت لە بەردەوامبوون بۆ لەگەڵهێنانەوەی ژمارەی پەیامەکان؟',
	'RESYNC_POST_MARKING'	=> 'لەگەڵهێنانەوەی بابەتە خاڵکراوەکان',
	'RESYNC_POST_MARKING_CONFIRM'	=> 'دڵنیایت لە بەردەوامبوون بۆ لەگەڵهێنانەوەی بابەتە خاڵکراوەکان؟',
	'RESYNC_POST_MARKING_EXPLAIN'	=> 'یەکەم هەموو بابەتەکان دەستنیشان مەکە و دواتر بابەتی دەستنیشان کراوی دروست کە هیچ چالاکییەکیان بینیوە لەکاتی شەش مانگی ڕۆیشتوودا.',
	'RESYNC_STATS'	=> 'لەگەڵهێنانەوەی ئامارەکان',
	'RESYNC_STATS_CONFIRM'	=> 'دڵنیایت کە بەردەوامبوون بۆ لەگەڵهێنانەوەی ئامارەکان؟',
	'RESYNC_STATS_EXPLAIN'	=> 'ژماردنەوەی کۆی ژمارەی پەیامەکان ،بابەتەکان بەکارهێنەران لەگەڵ پەڕگەکان.',
	'RUN'	=> 'ئێستا کاری پێبکە',
	'STATISTIC'	=> 'ئامارەکان',
	'STATISTIC_RESYNC_OPTIONS'	=> 'لەگەڵهێنانەوەی یان دانانەوەی ئامارەکان',
	'TOPICS_PER_DAY'	=> 'بابەتەکان بۆ هەر ڕۆژێک',
	'UPLOAD_DIR_SIZE'	=> 'قەبارەی هاوپێچە نێردراوەکان',
	'USERS_PER_DAY'	=> 'بەکارهێنەران بۆ هەر ڕۆژێک',
	'VALUE'	=> 'نرخ',
	'VERSIONCHECK_FAIL'			=> 'شکستی هێنا لە بەدەستهێنانی زانیاری دوا وەشان',
	'VERSIONCHECK_FORCE_UPDATE'	=> 'بپشکنەوە بۆ وەشان',
	'VIEW_ADMIN_LOG'	=> 'لۆگی بەڕێوەبەر ببینە',
	'VIEW_INACTIVE_USERS'	=> 'بەکارهێنەرە ناچالاکەکان ببینە',
	'WELCOME_PHPBB'	=> 'بەخێربێیت بۆ phpBB',
	'WRITABLE_CONFIG'	=> 'پەڕگەی دیمەنت (config.php) پێشووتر بنووس-جیهانییە. بەتوندی هانت دەدەین بۆ گۆڕینی دەسەڵاتەکان بۆ 640 یان بەلایەنی کەم بۆ 644 (بۆ نموونە: <a href="http://en.wikipedia.org/wiki/Chmod" rel="external">chmod</a> 640 config.php)',
	'INACTIVE_DATE'	=> 'ڕێکەوتی ناچالاکبوون',
	'INACTIVE_REASON'	=> 'هۆکار',
	'INACTIVE_REASON_MANUAL'	=> 'هەژمار لەلایەن بەڕێوەبەرەوە ناچالاک کرا',
	'INACTIVE_REASON_PROFILE'	=> 'وردەکارییەکانی پڕۆفایل گۆڕدرا',
	'INACTIVE_REASON_REGISTER'	=> 'هەژماری تۆمارکراوی نوێ',
	'INACTIVE_REASON_REMIND'	=> 'چالاککردنەوەی ناچاریی هەژماری بەکارهێنەر',
	'INACTIVE_REASON_UNKNOWN'	=> 'نەزانراو',
	'INACTIVE_USERS'	=> 'بەکارهێنەرە ناچالاکەکان',
	'INACTIVE_USERS_EXPLAIN'	=> 'ئەو لیستە لیستێکی ئەو بەکارهێنەرانەیە کە تۆماربوون بەڵام ئەو هەژمارانەی کە چالاک نین. دەتوانی ئەو بەکارهێنەرانە چالاک بکەی ،بسڕیتەوە یان بیربێنیتەوە بە ناردنی ئیمەیڵێک ئەگەر ئارەزووت کرد.',
	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'ئەوە لیستێکی دوایین 10 ئەندامی تۆماربووە کە هەژماری ناچالاکیان هەیە. لیستێکی تەواو بەردەستە لە مێنوی جێگرەوە یان بەدواکەوتنی بەستەرەکەی خوارەوە کەلەوێ دەتوانی ئەو بەکارهێنەرانە چالاکیان بکەیت ،بیانسڕیتەوە یان بیربێنیتەوە بە ناردنی ئیمەیڵێک ئەگەر ئارەزووت کرد.',
	'NO_INACTIVE_USERS'	=> 'بەکارهێنەری ناچالاک نییە',
	'SORT_INACTIVE'	=> 'ڕێکەوتی ناچالاکبوون',
	'SORT_LAST_VISIT'	=> 'دوا سەردان',
	'SORT_REASON'	=> 'هۆکار',
	'SORT_REG_DATE'	=> 'ڕێکەوتی خۆتۆمارکردن',
	'SORT_LAST_REMINDER'=> 'دوا بیرهێنانەوە',
	'SORT_REMINDER'		=> 'بیرهێنانەوە نێردرا',
	'USER_IS_INACTIVE'	=> 'بەکارهێنەر ناچالاکە',
	'EXPLAIN_SEND_STATISTICS'	=> 'تکایە زانیاری بنێرە دەربارەی ڕاژەکەت و دیمەنکردنی مەکۆ بۆ phpBB بۆ خەمڵاندنی ئامارکاری. هەموو ئەو زانیارییەی کە بتوانرێ تۆ بناسێنێ یان وێبگەکەت سڕاوەتەوە - داتاکە بەتەواوی <strong>نەناسراوە</strong>. ئێمە بڕیاری بنەڕەتین دەربارەی وەشانەکانی داهاتووی phpBB لەسەر ئەو زانیارییە. ئامارەکان دروستکراون بە بەردەستی گشتی. هەروەها ئێمە ئەو داتایە بەشداردەکەین لەگەڵ پرۆژەی PHP ,زمانی بەرنامەداڕێژی پێدروستکراوی phpBB.',
	'EXPLAIN_SHOW_STATISTICS'	=> 'بەکارهێنانی دوگمەکەی خوارەوە دەتوانی هەموو ئەو گۆڕاوانە پێشبینین بکەیت کە دەنێردرێ.',
	'DONT_SEND_STATISTICS'		=> 'بگەڕێوە بۆ کۆنترۆڵ پانێڵی بەڕێوەبەرایەتی ئەگەر ئارەزوو ناکەیت بۆ ناردنی زانیاری ئامارکاری بۆ phpBB.',
	'GO_ACP_MAIN'				=> 'بڕۆ بۆ پەڕەی دەستپێکی ACP',
	'HIDE_STATISTICS'			=> 'وردەکارییەکان بشارەوە',
	'SEND_STATISTICS'			=> 'زانیارییە ئامارییەکان بنێرە',
	'SHOW_STATISTICS'			=> 'وردەکارییەکان پیشان بدە',
	'THANKS_SEND_STATISTICS'	=> 'سوپاس بۆ ناردنی زانیاریت.',
	'LOG_ACL_ADD_USER_GLOBAL_U_'	=> '<strong>دەسەڵاتی بەکارهێنەران زیادکرا یان دەستکاریکرا</strong><br />» %s',
	'LOG_ACL_ADD_GROUP_GLOBAL_U_'	=> '<strong>دەسەڵاتی گرووپەکان زیادکرا یان دەستکاریکرا</strong><br />» %s',
	'LOG_ACL_ADD_USER_GLOBAL_M_'	=> '<strong>دەسەڵاتی چاودێرە جیهانییەکان زیادکرا یان دەستکاریکرا</strong><br />» %s',
	'LOG_ACL_ADD_GROUP_GLOBAL_M_'	=> '<strong>گرووپی دەسەڵاتی چاودێرە جیهانییەکان زیادکرا یان دەستکاریکرا</strong><br />» %s',
	'LOG_ACL_ADD_USER_GLOBAL_A_'	=> '<strong>دەسەڵاتی بەڕێوەبەران زیادکرا یان دەستکاریکرا</strong><br />» %s',
	'LOG_ACL_ADD_GROUP_GLOBAL_A_'	=> '<strong>گرووپی دەسەڵاتی بەڕێوەبەران زیادکرا یان دەستکاریکرا</strong><br />» %s',
	'LOG_ACL_ADD_ADMIN_GLOBAL_A_'	=> '<strong>بەڕێوەبەران زیادکران یان دەستکاریکران</strong><br />» %s',
	'LOG_ACL_ADD_MOD_GLOBAL_M_'	=> '<strong>چاودێرانی جیهانیی زیادکران یان دەستکاریکران</strong><br />» %s',
	'LOG_ACL_ADD_USER_LOCAL_F_'	=> '<strong>بەکارهێنەری مەکۆ زیادکرا یان دەستکاریکرا</strong> لە %1$s<br />» %2$s',
	'LOG_ACL_ADD_USER_LOCAL_M_'	=> '<strong>چاودێرانی مەکۆ زیادکران یان دەستکاریکران</strong> لە %1$s<br />» %2$s',
	'LOG_ACL_ADD_GROUP_LOCAL_F_'	=> '<strong>گرووپەکانی مەکۆ زیادکران یان دەستکاریکران</strong> لە %1$s<br />» %2$s',
	'LOG_ACL_ADD_GROUP_LOCAL_M_'	=> '<strong>گرووپی چاودێران زیادکرا یان دەستکاریکرا</strong> لە %1$s<br />» %2$s',
	'LOG_ACL_ADD_MOD_LOCAL_M_'	=> '<strong>چاودێرە زیادکراوەکان یان دەستکاریکراوەکان</strong> لە %1$s<br />» %2$s',
	'LOG_ACL_ADD_FORUM_LOCAL_F_'	=> '<strong>دەسەڵاتەکانی مەکۆ زیادکران یان دەستکاریکران</strong> لە %1$s<br />» %2$s',
	'LOG_ACL_DEL_ADMIN_GLOBAL_A_'	=> '<strong>بەڕێوەبەرە سڕاوەکان</strong><br />» %s',
	'LOG_ACL_DEL_MOD_GLOBAL_M_'	=> '<strong>چاودێرە جیهانییە سڕاوەکان</strong><br />» %s',
	'LOG_ACL_DEL_MOD_LOCAL_M_'	=> '<strong>چاودێرە سڕاوەکان</strong> لە %1$s<br />» %2$s',
	'LOG_ACL_DEL_FORUM_LOCAL_F_'	=> '<strong>دەسەڵاتی بەکارهێنەر/گرووپی مەکۆی سڕاوە</strong> لە %1$s<br />» %2$s',
	'LOG_ACL_TRANSFER_PERMISSIONS'	=> '<strong>دەسەڵاتەکان گواسترانەوە لە</strong><br />» %s',
	'LOG_ACL_RESTORE_PERMISSIONS'	=> '<strong>دەسەڵاتە هەبووەکان گەڕێندرانەوە لەدوای بەکارهێنانی لە</strong> <br />» %s',
	'LOG_ADMIN_AUTH_FAIL'	=> '<strong>سەرنەکەوتنی هەوڵی چوونەژوورەوەی بەڕێوەبەر</strong>',
	'LOG_ADMIN_AUTH_SUCCESS'	=> '<strong>چوونەژوورەوەی سەرکەوتووانەی بەڕێوەبەر</strong>',
	'LOG_ATTACHMENTS_DELETED'	=> '<strong>هاوپێچە سڕاوەکانی بەکارهێنەر</strong><br />» %s',
	'LOG_ATTACH_EXT_ADD'	=> '<strong>گەیەنەرەی دەستکاریکراو یان زیادکراوی هاوپێچەکان</strong><br />» %s',
	'LOG_ATTACH_EXT_DEL'	=> '<strong>گەیەنەرەی سڕاوەی هاوپێچ</strong><br />» %s',
	'LOG_ATTACH_EXT_UPDATE'	=> '<strong>گەیەنەرەی نوێکراوەی هاوپێچ</strong><br />» %s',
	'LOG_ATTACH_EXTGROUP_ADD'	=> '<strong>گرووپی گەیەنەرەی زیادکراو</strong><br />» %s',
	'LOG_ATTACH_EXTGROUP_EDIT'	=> '<strong>گرووپی گەیەنەرەی دەستکاریکراو</strong><br />» %s',
	'LOG_ATTACH_EXTGROUP_DEL'	=> '<strong>گرووپی گەیەنەرەی سڕاوە</strong><br />» %s',
	'LOG_ATTACH_FILEUPLOAD'	=> '<strong>پەڕگەی هەتیو بارکرا بۆ پەیامی</strong><br />» ID %1$d - %2$s',
	'LOG_ATTACH_ORPHAN_DEL'	=> '<strong>پەڕگەی هەتیو سڕایەوە</strong><br />» %s',
	'LOG_BAN_EXCLUDE_USER'	=> '<strong>بەکارهێنەری دەرهاتوو لە ڕاگرتنی</strong> بۆ هۆکاری “<em>%1$s</em>”<br />» %2$s',
	'LOG_BAN_EXCLUDE_IP'	=> '<strong>IP ــی دەرهاتوو لە ڕاگرتنی</strong> بۆ هۆکاری “<em>%1$s</em>”<br />» %2$s',
	'LOG_BAN_EXCLUDE_EMAIL'	=> '<strong>ئیمەیڵی دەرهاتوو لە ڕاگرتنی</strong> بۆ هۆکاری “<em>%1$s</em>”<br />» %2$s',
	'LOG_BAN_USER'	=> '<strong>بەکارهێنەری ڕاگیراو</strong> بۆ هۆکاری “<em>%1$s</em>”<br />» %2$s',
	'LOG_BAN_IP'	=> '<strong>IP ــی ڕاگیراو</strong> بۆ هۆکاری “<em>%1$s</em>”<br />» %2$s',
	'LOG_BAN_EMAIL'	=> '<strong>ئیمەیڵی ڕاگیراو</strong> بۆ هۆکاری “<em>%1$s</em>”<br />» %2$s',
	'LOG_UNBAN_USER'	=> '<strong>بەکارهێنەری ڕانەگیراو</strong><br />» %s',
	'LOG_UNBAN_IP'	=> '<strong>IP ــی ڕانەگیراو</strong><br />» %s',
	'LOG_UNBAN_EMAIL'	=> '<strong>ئیمەیڵی ڕانەگیراو</strong><br />» %s',
	'LOG_BBCODE_ADD'	=> '<strong>BBCode ــی نوێ زیادبکە</strong><br />» %s',
	'LOG_BBCODE_EDIT'	=> '<strong>BBCode ــی دەستکاریکراو</strong><br />» %s',
	'LOG_BBCODE_DELETE'	=> '<strong>BBCode ـی سڕاوە</strong><br />» %s',
	'LOG_BOT_ADDED'	=> '<strong>بووتی نوێ زیادکرا</strong><br />» %s',
	'LOG_BOT_DELETE'	=> '<strong>بووتی سڕاوە</strong><br />» %s',
	'LOG_BOT_UPDATED'	=> '<strong>بووتی چالاک نوێکرایەوە</strong><br />» %s',
	'LOG_CLEAR_ADMIN'	=> '<strong>لۆگی پاککراوی بەڕێوەبەر</strong>',
	'LOG_CLEAR_CRITICAL'	=> '<strong>لۆگی پاککراوی هەڵە</strong>',
	'LOG_CLEAR_MOD'	=> '<strong>لۆگی پاککراوی چاودێر</strong>',
	'LOG_CLEAR_USER'	=> '<strong>لۆگی پاککراوی بەکارهێنەر</strong><br />» %s',
	'LOG_CLEAR_USERS'	=> '<strong>لۆگی پاککراوی بەکارهێنەران</strong>',
	'LOG_CONFIG_ATTACH'	=> '<strong>ڕێکخستنە گۆڕاوەکانی هاوپێچ</strong>',
	'LOG_CONFIG_AUTH'	=> '<strong>ڕێکخستنە گۆڕاوەکانی پەسەندکردن</strong>',
	'LOG_CONFIG_AVATAR'	=> '<strong>ڕێکخستنە گۆڕاوەکانی وێنۆچکە</strong>',
	'LOG_CONFIG_COOKIE'	=> '<strong>ڕێکخستنە گۆڕاوەکانی شەکرۆکە</strong>',
	'LOG_CONFIG_EMAIL'	=> '<strong>ڕێکخستنە گۆڕاوەکانی ئیمەیڵ</strong>',
	'LOG_CONFIG_FEATURES'	=> '<strong>تایبەتمەندییە گۆڕاوەکانی مەکۆ</strong>',
	'LOG_CONFIG_LOAD'	=> '<strong>ڕێکخستنە گۆڕاوەکانی بارکردن</strong>',
	'LOG_CONFIG_MESSAGE'	=> '<strong>ڕێکخستنە گۆڕاوەکانی پەیامی تایبەت</strong>',
	'LOG_CONFIG_POST'	=> '<strong>ڕێکخستنە گۆڕاوەکانی پەیام</strong>',
	'LOG_CONFIG_REGISTRATION'	=> '<strong>ڕێکخستنە گۆڕاوەکانی تۆماربوونی بەکارهێنەر</strong>',
	'LOG_CONFIG_FEED'		=> '<strong>ڕێکخستنە گۆڕاوەکانی کۆنووسی feeds</strong>',
	'LOG_CONFIG_SEARCH'	=> '<strong>ڕێکخستنە گۆڕاوەکانی گەڕان</strong>',
	'LOG_CONFIG_SECURITY'	=> '<strong>ڕێکخستنە گۆڕاوەکانی پاراستن</strong>',
	'LOG_CONFIG_SERVER'	=> '<strong>ڕێکخستنە گۆڕاوەکانی ڕاژە</strong>',
	'LOG_CONFIG_SETTINGS'	=> '<strong>ڕێکخستنە گۆڕاوەکانی مەکۆ</strong>',
	'LOG_CONFIG_SIGNATURE'	=> '<strong>ڕێکخستنە گۆڕاوەکانی واژۆ</strong>',
	'LOG_CONFIG_VISUAL'			=> '<strong>ڕێکخستنە گۆڕاوەکانی دژە-سپام</strong>',
	'LOG_APPROVE_TOPIC'	=> '<strong>بابەتی پەسەندکراو</strong><br />» %s',
	'LOG_BUMP_TOPIC'	=> '<strong>بابەتی پێکدادراوی بەکارهێنەر</strong><br />» %s',
	'LOG_DELETE_POST'	=> '<strong>پەیامی سڕاوە</strong><br />» %s',
	'LOG_DELETE_SHADOW_TOPIC'	=> '<strong>سێبەری سڕاوەی بابەت</strong><br />» %s',
	'LOG_DELETE_TOPIC'	=> '<strong>بابەتی سڕاوە</strong><br />» %s',
	'LOG_FORK'	=> '<strong>بابەتی لەبەرگیراوە</strong><br />» لە %s',
	'LOG_LOCK'	=> '<strong>بابەتی داخراو</strong><br />» %s',
	'LOG_LOCK_POST'	=> '<strong>پەیامی داخراو</strong><br />» %s',
	'LOG_MERGE'	=> '<strong>پەیامە لکێندراوەکان</strong> بۆناو بابەتی<br />» %s',
	'LOG_MOVE'	=> '<strong>بابەتی گواستراوە</strong><br />» لە %1$s بۆ %2$s',
	'LOG_PM_REPORT_CLOSED'		=> '<strong>ڕاپۆرتی داخراوی پەیامی تایبەت</strong><br />» %s',
	'LOG_PM_REPORT_DELETED'		=> '<strong>ڕاپۆرتی سڕاوەی پەیامی تایبەت</strong><br />» %s',
	'LOG_POST_APPROVED'	=> '<strong>پەیامی پەسەندکراو</strong><br />» %s',
	'LOG_POST_DISAPPROVED'	=> '<strong>پەیامی پەسەندنەکراو “%1$s” لەگەڵ ئەم هۆکارانە</strong><br />» %2$s',
	'LOG_POST_EDITED'	=> '<strong>پەیامی دەستکاریکراو “%1$s” نووسراو لەلایەن</strong><br />» %2$s',
	'LOG_REPORT_CLOSED'	=> '<strong>ڕاپۆرتی داخراو</strong><br />» %s',
	'LOG_REPORT_DELETED'	=> '<strong>ڕاپۆرتی سڕاوە</strong><br />» %s',
	'LOG_SPLIT_DESTINATION'	=> '<strong>پەیامی جیای گواستراوە</strong><br />» بۆ %s',
	'LOG_SPLIT_SOURCE'	=> '<strong>پەیامە جیاکراوەکان</strong><br />» لە %s',
	'LOG_TOPIC_APPROVED'	=> '<strong>بابەتی پەسەندکراو</strong><br />» %s',
	'LOG_TOPIC_DISAPPROVED'	=> '<strong>بابەتی پەسەندنەکراو “%1$s” لەگەڵ ئەم هۆکارانە</strong><br />%2$s',
	'LOG_TOPIC_RESYNC'	=> '<strong>لەگەڵهاتنەوەی ژمێریاری بابەت</strong><br />» %s',
	'LOG_TOPIC_TYPE_CHANGED'	=> '<strong>جۆری گۆڕاوی بابەت</strong><br />» %s',
	'LOG_UNLOCK'	=> '<strong>بابەتی دانەخراو</strong><br />» %s',
	'LOG_UNLOCK_POST'	=> '<strong>پەیامی دانەخراو</strong><br />» %s',
	'LOG_DISALLOW_ADD'	=> '<strong>ناوی بەکارهێنەری زیادکراوی ڕێگانەدراو</strong><br />» %s',
	'LOG_DISALLOW_DELETE'	=> '<strong>ناوی بەکارهێنەری ڕێگانەدراوی سڕاوە</strong>',
	'LOG_DB_BACKUP'	=> '<strong>پاڵپشتی بنکەدراوە</strong>',
	'LOG_DB_DELETE'	=> '<strong>پاڵپشتی سڕاوەی بنکەدراوە</strong>',
	'LOG_DB_RESTORE'	=> '<strong>پاڵپشتی هێنراوەی بنکەدراوە</strong>',
	'LOG_DOWNLOAD_EXCLUDE_IP'	=> '<strong>لە لیستی داگرتن IP/hostname بخەرەناو</strong><br />» %s',
	'LOG_DOWNLOAD_IP'	=> '<strong>زیادکراوی IP/hostname بۆ لیستی داگرتن</strong><br />» %s',
	'LOG_DOWNLOAD_REMOVE_IP'	=> '<strong>IP/hostname ــی سڕاوە لە لیستی داگرتن</strong><br />» %s',
	'LOG_ERROR_JABBER'	=> '<strong>هەڵەی جابەر</strong><br />» %s',
	'LOG_ERROR_EMAIL'	=> '<strong>هەڵەی ئیمەیڵ</strong><br />» %s',
	'LOG_FORUM_ADD'	=> '<strong>مەکۆی دروستکراوی نوێ</strong><br />» %s',
	'LOG_FORUM_COPIED_PERMISSIONS'			=> '<strong>دەسەڵاتی لەبەرگیراوەی مەکۆ</strong> لە %1$s<br />» %2$s',
	'LOG_FORUM_DEL_FORUM'	=> '<strong>مەکۆی سڕاوە</strong><br />» %s',
	'LOG_FORUM_DEL_FORUMS'	=> '<strong>مەکۆی سڕاوە لەگەڵ ژێرمەکۆکانی</strong><br />» %s',
	'LOG_FORUM_DEL_MOVE_FORUMS'	=> '<strong>مەکۆی سڕاوە لەگەڵ گواستنەوەی ژێرمەکۆکانی</strong> بۆ %1$s<br />» %2$s',
	'LOG_FORUM_DEL_MOVE_POSTS'	=> '<strong>مەکۆی سڕاوە لەگەڵ گواستنەوەی پەیامەکانی</strong> بۆ %1$s<br />» %2$s',
	'LOG_FORUM_DEL_MOVE_POSTS_FORUMS'	=> '<strong>مەکۆ و ژێرمەکۆکان سڕدرانەوە پەیامەکان گوێزرانەوە </strong> بۆ %1$s<br />» %2$s',
	'LOG_FORUM_DEL_MOVE_POSTS_MOVE_FORUMS'	=> '<strong>مەکۆی سڕاوە ،پەیامی گواستراوە</strong> بۆ %1$s <strong>لەگەڵ ژێرمەکۆکان</strong> to %2$s<br />» %3$s',
	'LOG_FORUM_DEL_POSTS'	=> '<strong>مەکۆ و پەیامەکان سڕدرانەوە</strong><br />» %s',
	'LOG_FORUM_DEL_POSTS_FORUMS'	=> '<strong>مەکۆ و پەیامەکانی و ژێرمەکۆکان سڕدرانەوە</strong><br />» %s',
	'LOG_FORUM_DEL_POSTS_MOVE_FORUMS'	=> '<strong>مەکۆکان و پەیامەکانی سڕدرانەوە، ژێرمەکۆکان گوێزرانەوە</strong> بۆ %1$s<br />» %2$s',
	'LOG_FORUM_EDIT'	=> '<strong>وردەکاری دەستکاریکراوی مەکۆ</strong><br />» %s',
	'LOG_FORUM_MOVE_DOWN'	=> '<strong>مەکۆی گواستراوە</strong> %1$s <strong>لەخوارەوە</strong> %2$s',
	'LOG_FORUM_MOVE_UP'	=> '<strong>مەکۆی گواستراوە</strong> %1$s <strong>لەسەرەوە</strong> %2$s',
	'LOG_FORUM_SYNC'	=> '<strong>لەگەڵ-هێنانەوەی مەکۆ</strong><br />» %s',
	'LOG_GENERAL_ERROR'	=> '<strong>هەڵەیەکی گشتی ڕوویدا</strong>: %1$s <br />» %2$s',
	'LOG_GROUP_CREATED'	=> '<strong>گرووپی نوێی بەکارهێنەر دروستکرا</strong><br />» %s',
	'LOG_GROUP_DEFAULTS'	=> '<strong>گرووپی “%1$s” کرا بە بنەڕەت بۆ ئەندامان</strong><br />» %2$s',
	'LOG_GROUP_DELETE'	=> '<strong>گرووپی بەکارهێنەر سرایەوە</strong><br />» %s',
	'LOG_GROUP_DEMOTED'	=> '<strong>پێشڕەوان دابەزێنران لە گرووپی بەکارهێنەر</strong> %1$s<br />» %2$s',
	'LOG_GROUP_PROMOTED'	=> '<strong>ئەندامان بەرزکرانەوە بۆ پێشڕەوی گرووپی بەکارهێنەر</strong> %1$s<br />» %2$s',
	'LOG_GROUP_REMOVE'	=> '<strong>ئەندامان سڕانەوە لە گرووپی بەکارهێنەر</strong> %1$s<br />» %2$s',
	'LOG_GROUP_UPDATED'	=> '<strong>وردەکارییەکانی گرووپی بەکارهێنەر نوێکرایەوە</strong><br />» %s',
	'LOG_MODS_ADDED'	=> '<strong>پێشڕەوی نوێ زیادکرا بۆ گرووپی بەکارهێنەر</strong> %1$s<br />» %2$s',
	'LOG_USERS_ADDED'	=> '<strong>ئەندامی زیادکراوی نوێ بۆ گرووپی بەکارهێنەر</strong> %1$s<br />» %2$s',
	'LOG_USERS_APPROVED'	=> '<strong>بەکارهێنەران وەرگیران لە گرووپی بەکارهێنەر</strong> %1$s<br />» %2$s',
	'LOG_USERS_PENDING'		=> '<strong>بەکارهێنەران داواینکردووە بۆ بەشداری لە گرووپی بەکارهێنەری “%1$s” لەگەڵ وەرگیرانیان</strong><br />» %2$s',

	'LOG_IMAGE_GENERATION_ERROR'	=> '<strong>هەڵە لەکاتی دروستکردنی وێنە</strong><br />» هەڵە لە %1$s لە هێڵی %2$s: %3$s',
	'LOG_IMAGESET_ADD_DB'	=> '<strong> زیادکراوی نوێی imageset بۆ بنکەدراوە</strong><br />» %s',
	'LOG_IMAGESET_ADD_FS'	=> '<strong>زیادکراوی نوێی imageset لە پەڕگەسیستەم</strong><br />» %s',
	'LOG_IMAGESET_DELETE'	=> '<strong>imagesetــی سڕاوە</strong><br />» %s',
	'LOG_IMAGESET_EDIT_DETAILS'	=> '<strong>وردەکاری imageset دەستکاریکراو</strong><br />» %s',
	'LOG_IMAGESET_EDIT'	=> '<strong>دەستکاریکراو imageset</strong><br />» %s',
	'LOG_IMAGESET_EXPORT'	=> '<strong>imagesetــی هێنراو</strong><br />» %s',
	'LOG_IMAGESET_LANG_MISSING'	=> '<strong>Imageset ونکردوە “%2$s” </strong><br />» %1$s',
	'LOG_IMAGESET_LANG_REFRESHED'	=> '<strong>نوێکراوەی “%2$s” بۆ imageset</strong><br />» %1$s',
	'LOG_IMAGESET_REFRESHED'	=> '<strong>imageset تازەکراوە</strong><br />» %s',
	'LOG_INACTIVE_ACTIVATE'	=> '<strong>بەکارهێنەری چالاککراوی ناچالاک</strong><br />» %s',
	'LOG_INACTIVE_DELETE'	=> '<strong>بەکارهێنەری ناچالاکی سڕاوە</strong><br />» %s',
	'LOG_INACTIVE_REMIND'	=> '<strong>ئیمەیڵی بیرهێنانەوە بنێرە بۆ بەکارهێنەرە ناچالاکەکا</strong><br />» %s',
	'LOG_INSTALL_CONVERTED'	=> '<strong>گۆڕدرا لە %1$s بۆ phpBB %2$s</strong>',
	'LOG_INSTALL_INSTALLED'	=> '<strong>phpBBــی دامەزراو %s</strong>',
	'LOG_IP_BROWSER_FORWARDED_CHECK'	=> '<strong>دانیشتنی IP/browser/X_FORWARDED_FOR بپشکنە سەرنەکەوتن</strong><br />»IPــی بەکارهێنەر “<em>%1$s</em>” پشکنرا دژی IP “<em>%2$s</em>”, وێبگەڕی بەکارهێنەر “<em>%3$s</em>” پشکنرا دژی دانیشتنی وێبگەڕ “<em>%4$s</em>” لەگەڵ X_FORWARDED_FOR بەکارهێنەر “<em>%5$s</em>” پشکنرا دژی دانیشتنی X_FORWARDED_FOR “<em>%6$s</em>”.',
	'LOG_JAB_CHANGED'	=> '<strong>هەژماری گۆڕدراوی جابەر</strong>',
	'LOG_JAB_PASSCHG'	=> '<strong>تێپەڕەوشەی گۆڕدراوی جابەر</strong>',
	'LOG_JAB_REGISTER'	=> '<strong>هەژماری تۆماربووی جابەر</strong>',
	'LOG_JAB_SETTINGS_CHANGED'	=> '<strong>ڕێکخستنەکانی جابەر گۆڕدران</strong>',
	'LOG_LANGUAGE_PACK_DELETED'	=> '<strong>گورزەی زمانی سڕاوە</strong><br />» %s',
	'LOG_LANGUAGE_PACK_INSTALLED'	=> '<strong>گورزەی زمانی دامەزراو</strong><br />» %s',
	'LOG_LANGUAGE_PACK_UPDATED'	=> '<strong>وردەکاری نوێکراوەی گورزەی زمان</strong><br />» %s',
	'LOG_LANGUAGE_FILE_REPLACED'	=> '<strong>پەڕگەی لەجێدانراوی زمان</strong><br />» %s',
	'LOG_LANGUAGE_FILE_SUBMITTED'	=> '<strong>پەڕگەی نێردراوی زمان و دانراو لە بوخچەی کۆگا</strong><br />» %s',
	'LOG_MASS_EMAIL'	=> '<strong>ئیمەیڵی گشتی بنێرە</strong><br />» %s',
	'LOG_MCP_CHANGE_POSTER'	=> '<strong>نێرەری گۆڕدراو لە بابەت “%1$s”</strong><br />» لە %2$s بۆ %3$s',
	'LOG_MODULE_DISABLE'	=> '<strong>یەکە ناچالاککراوە</strong><br />» %s',
	'LOG_MODULE_ENABLE'	=> '<strong>یەکە چالاککراوە</strong><br />» %s',
	'LOG_MODULE_MOVE_DOWN'	=> '<strong>یەکە بۆ خوارەوە جووڵاوە</strong><br />» %1$s لەخوارەوە %2$s',
	'LOG_MODULE_MOVE_UP'	=> '<strong>یەکە بۆ سەرەوە جووڵاوە</strong><br />» %1$s لەسەرەوە %2$s',
	'LOG_MODULE_REMOVED'	=> '<strong>یەکە سڕاوەتەوە</strong><br />» %s',
	'LOG_MODULE_ADD'	=> '<strong>یەکە زیادکرا</strong><br />» %s',
	'LOG_MODULE_EDIT'	=> '<strong>یەکە دەستکاریکرا</strong><br />» %s',
	'LOG_A_ROLE_ADD'	=> '<strong>یاسای بەڕێوەبەر زیادکرا</strong><br />» %s',
	'LOG_A_ROLE_EDIT'	=> '<strong>یاسای بەڕێوەبەر دەستکاریکرا</strong><br />» %s',
	'LOG_A_ROLE_REMOVED'	=> '<strong>یاسای بەڕێوەبەر سڕایەوە</strong><br />» %s',
	'LOG_F_ROLE_ADD'	=> '<strong>یاسای مەکۆ زیادکرا</strong><br />» %s',
	'LOG_F_ROLE_EDIT'	=> '<strong>یاسای مەکۆ دەستکاریکرا</strong><br />» %s',
	'LOG_F_ROLE_REMOVED'	=> '<strong>یاسای مەکۆ سڕایەوە</strong><br />» %s',
	'LOG_M_ROLE_ADD'	=> '<strong>یاسای چاودێر زیادکرا</strong><br />» %s',
	'LOG_M_ROLE_EDIT'	=> '<strong>یاسای چاودێر دەستکاریکرا</strong><br />» %s',
	'LOG_M_ROLE_REMOVED'	=> '<strong>یاسای چاودێر سڕایەوە</strong><br />» %s',
	'LOG_U_ROLE_ADD'	=> '<strong>یاسای بەکارهێنەر زیادکرا</strong><br />» %s',
	'LOG_U_ROLE_EDIT'	=> '<strong>یاسای بەکارهێنەر دەستکاریکرا</strong><br />» %s',
	'LOG_U_ROLE_REMOVED'	=> '<strong>یاسای بەکارهێنەر سڕایەوە</strong><br />» %s',
	'LOG_PROFILE_FIELD_ACTIVATE'	=> '<strong>خانەی پرۆفایل چالاککرا</strong><br />» %s',
	'LOG_PROFILE_FIELD_CREATE'	=> '<strong>خانەی پرۆفایل زیادکرا</strong><br />» %s',
	'LOG_PROFILE_FIELD_DEACTIVATE'	=> '<strong>خانەی پرۆفایل ناچالاککرا</strong><br />» %s',
	'LOG_PROFILE_FIELD_EDIT'	=> '<strong>خانەی پرۆفایل گۆڕدرا</strong><br />» %s',
	'LOG_PROFILE_FIELD_REMOVED'	=> '<strong>خانەی پرۆفایل سڕایەوە</strong><br />» %s',
	'LOG_PRUNE'	=> '<strong>مەکۆ وشککراوەکان</strong><br />» %s',
	'LOG_AUTO_PRUNE'	=> '<strong>مەکۆ خۆکار-وشککراوان</strong><br />» %s',
	'LOG_PRUNE_USER_DEAC'	=> '<strong>بەکارهێنەران ناچالاککران</strong><br />» %s',
	'LOG_PRUNE_USER_DEL_DEL'	=> '<strong>بەکارهێنەران وشککران و پەیامەکان سڕانەوە</strong><br />» %s',
	'LOG_PRUNE_USER_DEL_ANON'	=> '<strong>بەکارهێنەران وشککران و پەیامەکان نەناسراوکران</strong><br />» %s',
	'LOG_PURGE_CACHE'	=> '<strong>ئەرشیفی پاککراو</strong>',
	'LOG_PURGE_SESSIONS'		=> '<strong>دانیشتنە پاککراوەکان</strong>',
	'LOG_RANK_ADDED'	=> '<strong>پلەی زیادکراوی نوێ</strong><br />» %s',
	'LOG_RANK_REMOVED'	=> '<strong>پلەی سڕاوە</strong><br />» %s',
	'LOG_RANK_UPDATED'	=> '<strong>پلەی نوێکراوە</strong><br />» %s',
	'LOG_REASON_ADDED'	=> '<strong>زیادکراوی هۆکاری ڕاپۆرت/ڕەتکردن</strong><br />» %s',
	'LOG_REASON_REMOVED'	=> '<strong>هۆکاری سڕاوەی ڕاپۆرت/ڕەتکردن</strong><br />» %s',
	'LOG_REASON_UPDATED'	=> '<strong>هۆکاری نوێکراوەی ڕاپۆرت/ڕەتکردن</strong><br />» %s',
	'LOG_REFERER_INVALID'	=> '<strong>بەردەستیی ئاماژەدان سەرنەکەوتن</strong><br />»ئاماژەکار بریتیی بوو “<em>%1$s</em>”. داواکە ڕەتکرایەوە و دانیشتنەکەش کوژرا.',
	'LOG_RESET_DATE'	=> '<strong>بەرواری دەستپێکردنی مەکۆ دانرایەوە</strong>',
	'LOG_RESET_ONLINE'	=> '<strong>زۆرترین بەکارهێنەری سەرهێڵ دانرایەوە</strong>',
	'LOG_RESYNC_POSTCOUNTS'	=> '<strong>ژمارەی پەیامی بەکارهێنەران کۆنووسکرایەوە</strong>',
	'LOG_RESYNC_POST_MARKING'	=> '<strong>بابەتە خاڵکراوەکان کۆنووسکرانەوە</strong>',
	'LOG_RESYNC_STATS'	=> '<strong>بابەت ،پەیام لەگەڵ ئامارەکانی بەکارهێنەر کۆنووسکرانەوە</strong>',
	'LOG_SEARCH_INDEX_CREATED'	=> '<strong>پێڕستی گەڕانی دروستکراو بۆ</strong><br />» %s',
	'LOG_SEARCH_INDEX_REMOVED'	=> '<strong>پێڕستی گەڕانی سڕاوە بۆ</strong><br />» %s',
	'LOG_STYLE_ADD'	=> '<strong>شێوازی زیادکراوی نوێ</strong><br />» %s',
	'LOG_STYLE_DELETE'	=> '<strong>شێوازی سڕاوە</strong><br />» %s',
	'LOG_STYLE_EDIT_DETAILS'	=> '<strong>شێوازی دەستکاریکراو</strong><br />» %s',
	'LOG_STYLE_EXPORT'	=> '<strong>شێوازی هێنراو</strong><br />» %s',
	'LOG_TEMPLATE_ADD_DB'	=> '<strong>داڕێژەی نوێی زیادکراو بۆ بنکەدراوە</strong><br />» %s',
	'LOG_TEMPLATE_ADD_FS'	=> '<strong>داڕێژەی نوێی زیادکراو بۆ دانانی لەسەر پەڕگەسیستەم</strong><br />» %s',
	'LOG_TEMPLATE_CACHE_CLEARED'	=> '<strong>وەشانی ئەرشیفکراوە سڕاوەکانی داڕێژەیەکی بنکەداوە <em>%1$s</em></strong><br />» %2$s',
	'LOG_TEMPLATE_DELETE'	=> '<strong>دانراوی سڕاوەی داڕێژە</strong><br />» %s',
	'LOG_TEMPLATE_EDIT'	=> '<strong>دانراوی دەستکاریکراوی داڕێژە<em>%1$s</em></strong><br />» %2$s',
	'LOG_TEMPLATE_EDIT_DETAILS'	=> '<strong>وردەکاری دەستکاریکراوی داڕێژە</strong><br />» %s',
	'LOG_TEMPLATE_EXPORT'	=> '<strong>دانراوی هێنراوی داڕێژە</strong><br />» %s',
	'LOG_TEMPLATE_REFRESHED'	=> '<strong>دانراوی تازەکراوی داڕێژە</strong><br />» %s',
	'LOG_THEME_ADD_DB'	=> '<strong>شێوازی زیادکراوی نوێ بۆ بنکەدراوە</strong><br />» %s',
	'LOG_THEME_ADD_FS'	=> '<strong>شێوازی نوێی زیادکراو بۆ پەڕگەسیستەم</strong><br />» %s',
	'LOG_THEME_DELETE'	=> '<strong>شێواز سڕایەوە</strong><br />» %s',
	'LOG_THEME_EDIT_DETAILS'	=> '<strong>وردەکاری دەستکاریکراوی شێواز</strong><br />» %s',
	'LOG_THEME_EDIT'	=> '<strong>شێوازی دەستکاریکراو <em>%1$s</em></strong>',
	'LOG_THEME_EDIT_FILE'	=> '<strong>شێوازی دەستکاریکراو <em>%1$s</em></strong><br />» پەڕگەی دڵنیاکراو <em>%2$s</em>',
	'LOG_THEME_EXPORT'	=> '<strong>شێوازی هێنراو</strong><br />» %s',
	'LOG_THEME_REFRESHED'	=> '<strong>شێوازی تازەکراو</strong><br />» %s',
	'LOG_UPDATE_DATABASE'	=> '<strong>بنکەدراوەی نوێکراوە لە وەشانی %1$s بۆ وەشانی %2$s</strong>',
	'LOG_UPDATE_PHPBB'	=> '<strong>phpBB ــی نوێکراوە لە وەشانی %1$s بۆ وەشانی %2$s</strong>',
	'LOG_USER_ACTIVE'	=> '<strong>بەکارهێنەر چالاککرا</strong><br />» %s',
	'LOG_USER_BAN_USER'	=> '<strong>بەکارهێنەر ڕاگیراو لەڕێگای بەڕێوەبردنی بەکارهێنەران</strong> بۆ هۆکاری “<em>%1$s</em>”<br />» %2$s',
	'LOG_USER_BAN_IP'	=> '<strong>IP ــی ڕاگیراو لەڕێگای بەڕێوەبردنی بەکارهێنەران</strong> بۆ هۆکاری “<em>%1$s</em>”<br />» %2$s',
	'LOG_USER_BAN_EMAIL'	=> '<strong>ئیمەیڵی ڕاگیراو لەڕێگای بەڕێوەبردنی بەکارهێنەران</strong> بۆ هۆکاری “<em>%1$s</em>”<br />» %2$s',
	'LOG_USER_DELETED'	=> '<strong>بەکارهێنەری سڕاوە</strong><br />» %s',
	'LOG_USER_DEL_ATTACH'	=> '<strong>هەموو ئەو هاوپێچانە بسڕەوە کەکراون لەلایەن بەکارهێنەر</strong><br />» %s',
	'LOG_USER_DEL_AVATAR'	=> '<strong>وێنۆچکەی سڕاوەی بەکارهێنەر</strong><br />» %s',
	'LOG_USER_DEL_OUTBOX'	=> '<strong>بەتاڵکراوی دەرهاتووی بەکارهێنەر</strong><br />» %s',
	'LOG_USER_DEL_POSTS'	=> '<strong>هەموو ئەو پەیامانە بسڕەوە کە لەلایەن ئەو بەکارهێنەرە نووسراوە</strong><br />» %s',
	'LOG_USER_DEL_SIG'	=> '<strong>واژۆی سڕاوەی بەکارهێنەر</strong><br />» %s',
	'LOG_USER_INACTIVE'	=> '<strong>بەکارهێنەر ناچالاککرا</strong><br />» %s',
	'LOG_USER_MOVE_POSTS'	=> '<strong>پەیامە گواستراوەکانی بەکارهێنەر</strong><br />» پەیامەکان لەلایەن “%1$s” بۆ مەکۆی “%2$s”',
	'LOG_USER_NEW_PASSWORD'	=> '<strong>تێپەڕەوشەی گۆڕدراوی بەکارهێنەر</strong><br />» %s',
	'LOG_USER_REACTIVATE'	=> '<strong>بەزۆر چالاککردنی هەژماری بەکارهێنەر</strong><br />» %s',
	'LOG_USER_REMOVED_NR'	=> '<strong>ئاڵای تۆماربووی سڕاوەی نوێی بەکارهێنەر</strong><br />» %s',
	'LOG_USER_UPDATE_EMAIL'	=> '<strong>بەکارهێنەر “%1$s” ئیمەیڵی گۆڕی</strong><br />» لە “%2$s” بۆ “%3$s”',
	'LOG_USER_UPDATE_NAME'	=> '<strong>ناوی بەکارهێنەری گۆڕدراو</strong><br />» لە “%1$s” بۆ “%2$s”',
	'LOG_USER_USER_UPDATE'	=> '<strong>وردەکارییە نوێکراوەکانی بەکارهێنەر</strong><br />» %s',
	'LOG_USER_ACTIVE_USER'	=> '<strong>هەژماری بەکارهێنەر چالاککرا</strong>',
	'LOG_USER_DEL_AVATAR_USER'	=> '<strong>وێنۆچکەی بەکارهێنەر سڕایەوە</strong>',
	'LOG_USER_DEL_SIG_USER'	=> '<strong>واژۆی بەکارهێنەر سڕایەوە</strong>',
	'LOG_USER_FEEDBACK'	=> '<strong>feedbackــی زیادکراوی بەکارهێنەر</strong><br />» %s',
	'LOG_USER_GENERAL'	=> '<strong>دەروازە زیادکرا:</strong><br />» %s',
	'LOG_USER_INACTIVE_USER'	=> '<strong>هەژماری بەکارهێنەر نا-چالاککرا</strong>',
	'LOG_USER_LOCK'	=> '<strong>بەکارهێنەر بابەتی خۆی داخست</strong><br />» %s',
	'LOG_USER_MOVE_POSTS_USER'	=> '<strong>هەموو پەیامە گواستراوەکان بۆ مەکۆی</strong>» %s',
	'LOG_USER_REACTIVATE_USER'	=> '<strong>بەزۆر چالاککردنی هەژماری بەکارهێنەر</strong>',
	'LOG_USER_UNLOCK'	=> '<strong>بەکارهێنەر بابەتی خۆی کردەوە</strong><br />» %s',
	'LOG_USER_WARNING'	=> '<strong>ئاگاداری زیادکراوی بەکارهێنەر</strong><br />» %s',
	'LOG_USER_WARNING_BODY'	=> '<strong>ئەم ئاگادارکەرەوانە ئەم کێشانەیان تووشی بەکارهێنەرە کردووە</strong><br />» %s',
	'LOG_USER_GROUP_CHANGE'	=> '<strong>بەکارهێنەر گرووپی بنەڕەتی گۆڕی</strong><br />» %s',
	'LOG_USER_GROUP_DEMOTE'	=> '<strong>بەکارهێنەر دابەزێنرا وەکو پێشڕەوی گرووپی بەکارهێنەر</strong><br />» %s',
	'LOG_USER_GROUP_JOIN'	=> '<strong>بەکارهێنەر بەشداری گرووپ بوو</strong><br />» %s',
	'LOG_USER_GROUP_JOIN_PENDING'	=> '<strong>بەکارهێنەر بەشداری گرووپ بوو و پێویستی بە پەسەندکردنە</strong><br />» %s',
	'LOG_USER_GROUP_RESIGN'	=> '<strong>بەکارهێنەر ئەندامییەتی خستەوە بۆ گرووپی بەکارهێنەر</strong><br />» %s',
	'LOG_WARNING_DELETED'		=> '<strong>ئاگاداری سڕاوەی بەکارهێنەر</strong><br />» %s',
	'LOG_WARNINGS_DELETED'		=> '<strong>ئاگاداری %2$s سڕاوەی بەکارهێنەر</strong><br />» %1$s', // Example: '<strong>Deleted 2 user warnings</strong><br />» username'
	'LOG_WARNINGS_DELETED_ALL'	=> '<strong>هەموو ئاگادارییە سڕاوەکانی بەکارهێنەر</strong><br />» %s',
	'LOG_WORD_ADD'	=> '<strong>سانسۆری زیادکراوی وشە</strong><br />» %s',
	'LOG_WORD_DELETE'	=> '<strong>سانسۆری سڕاوەی وشە</strong><br />» %s',
	'LOG_WORD_EDIT'	=> '<strong>سانسۆری دەستکاریکراوی وشە</strong><br />» %s',
	'PARSE_BBCODE'						=> 'شیکاری BBCode',
	'PARSE_SMILIES'						=> 'شیکاری خەندەکان',
	'PARSE_URLS'						=> 'شیکاری بەستەرەکان',
	'PERMISSIONS_TRANSFERRED'			=> 'دەسەڵاتەکان گوازرانەوە',
	'PERMISSIONS_TRANSFERRED_EXPLAIN'	=> 'تۆ ئێستا دەسەڵاتت هەیە لە %1$s. دەتوانی مەکۆکە بگەڕێی لەگەڵ دەسەڵاتی ئەو بەکارهێنەرە ،بەڵام دەسەڵاتی بەڕێوەبەر نەگوێزراوەتەوە بۆ گەیشتن بە کۆنترۆڵ پانێڵی بەڕێوەبەرایەتی .تۆ دەتوانی <a href="%2$s"><strong>بگەڕێیەوە بۆ دەسەڵاتی دانراو</strong></a> هەر کاتێک ویستت.',
	
));

?>
